.. _download:

Download dhcpcanon
===================

You can download this project in either
`zip <http://github.com/juga0/dhcpcanon/zipball/master()>`__
or `tar <http://github.com/juga0/dhcpcanon/tarball/master>`__ formats.

You can also clone the project with Git by running:
    git clone git://github.com/juga0/dhcpcanon
